@@ -61,6 +61,7 @@ keymap = cytoolz.curry(keymap)
 map = cytoolz.curry(map)
 mapcat = cytoolz.curry(mapcat)
 memoize = cytoolz.curry(memoize)
+merge = cytoolz.curry(merge)
 merge_with = cytoolz.curry(merge_with)
 nth = cytoolz.curry(nth)
 partition = cytoolz.curry(partition)
@@ -75,6 +76,7 @@ sorted = cytoolz.curry(sorted)
 tail = cytoolz.curry(tail)
 take = cytoolz.curry(take)
 take_nth = cytoolz.curry(take_nth)
+topk = cytoolz.curry(topk)
 unique = cytoolz.curry(unique)
 update_in = cytoolz.curry(update_in)
 valfilter = cytoolz.curry(valfilter)
