@@ -1,6 +1,8 @@
 import cytoolz
 import cytoolz.curried
-from cytoolz.curried import take, first, second, sorted, merge_with, reduce
+from cytoolz.curried import (take, first, second, sorted, merge_with, reduce,
+                           merge)
+from collections import defaultdict
 from operator import add
 
 
@@ -12,6 +14,12 @@ def test_first():
     assert first is cytoolz.itertoolz.first
 
 
+def test_merge():
+    assert merge(factory=lambda: defaultdict(int))({1: 1}) == {1: 1}
+    assert merge({1: 1}) == {1: 1}
+    assert merge({1: 1}, factory=lambda: defaultdict(int)) == {1: 1}
+
+
 def test_merge_with():
     assert merge_with(sum)({1: 1}, {1: 2}) == {1: 3}
 
